You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2019/08/21 09:23:39 UTC

[camel] 03/03: CAMEL-13870: Fast property configuration of Camel endpoints. Work in progress.

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch CAMEL-13870
in repository https://gitbox.apache.org/repos/asf/camel.git

commit de202fba4c4c867007017592f495edf12bd4a7a2
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Wed Aug 21 11:23:18 2019 +0200

    CAMEL-13870: Fast property configuration of Camel endpoints. Work in progress.
---
 .../src/main/docs/atomix-map-component.adoc        |  2 +-
 .../src/main/docs/atomix-messaging-component.adoc  |  2 +-
 .../src/main/docs/atomix-multimap-component.adoc   |  2 +-
 .../src/main/docs/atomix-queue-component.adoc      |  2 +-
 .../src/main/docs/atomix-set-component.adoc        |  2 +-
 .../src/main/docs/atomix-value-component.adoc      |  2 +-
 .../dsl/AtomixMapEndpointBuilderFactory.java       | 68 +++++----------------
 .../dsl/AtomixMessagingEndpointBuilderFactory.java | 70 +++++-----------------
 .../dsl/AtomixMultiMapEndpointBuilderFactory.java  | 22 ++-----
 .../dsl/AtomixQueueEndpointBuilderFactory.java     | 68 +++++----------------
 .../dsl/AtomixSetEndpointBuilderFactory.java       | 68 +++++----------------
 .../dsl/AtomixValueEndpointBuilderFactory.java     | 68 +++++----------------
 12 files changed, 86 insertions(+), 290 deletions(-)

diff --git a/components/camel-atomix/src/main/docs/atomix-map-component.adoc b/components/camel-atomix/src/main/docs/atomix-map-component.adoc
index 67db23c..ed1d0a8 100644
--- a/components/camel-atomix/src/main/docs/atomix-map-component.adoc
+++ b/components/camel-atomix/src/main/docs/atomix-map-component.adoc
@@ -72,7 +72,7 @@ with the following path and query parameters:
 | *key* (common) | The key to use if none is set in the header or to listen for events for a specific key. |  | Object
 | *nodes* (common) | The address of the nodes composing the cluster. |  | String
 | *resultHeader* (common) | The header that wil carry the result. |  | String
-| *transport* (common) | Sets the Atomix transport. | io.atomix.catalyst.transport.netty.NettyTransport | Transport
+| *transportClassName* (common) | The class name (fqn) of the Atomix transport | io.atomix.catalyst.transport.netty.NettyTransport | String
 | *ttl* (common) | The resource ttl. |  | long
 | *bridgeErrorHandler* (consumer) | Allows for bridging the consumer to the Camel routing Error Handler, which mean any exceptions occurred while the consumer is trying to pickup incoming messages, or the likes, will now be processed as a message and handled by the routing Error Handler. By default the consumer will use the org.apache.camel.spi.ExceptionHandler to deal with exceptions, that will be logged at WARN or ERROR level and ignored. | false | boolean
 | *exceptionHandler* (consumer) | To let the consumer use a custom ExceptionHandler. Notice if the option bridgeErrorHandler is enabled then this option is not in use. By default the consumer will deal with exceptions, that will be logged at WARN or ERROR level and ignored. |  | ExceptionHandler
diff --git a/components/camel-atomix/src/main/docs/atomix-messaging-component.adoc b/components/camel-atomix/src/main/docs/atomix-messaging-component.adoc
index 4c6e80b..89fa55c 100644
--- a/components/camel-atomix/src/main/docs/atomix-messaging-component.adoc
+++ b/components/camel-atomix/src/main/docs/atomix-messaging-component.adoc
@@ -73,7 +73,7 @@ with the following path and query parameters:
 | *memberName* (common) | The Atomix Group member name |  | String
 | *nodes* (common) | The address of the nodes composing the cluster. |  | String
 | *resultHeader* (common) | The header that wil carry the result. |  | String
-| *transport* (common) | Sets the Atomix transport. | io.atomix.catalyst.transport.netty.NettyTransport | Transport
+| *transportClassName* (common) | The class name (fqn) of the Atomix transport | io.atomix.catalyst.transport.netty.NettyTransport | String
 | *bridgeErrorHandler* (consumer) | Allows for bridging the consumer to the Camel routing Error Handler, which mean any exceptions occurred while the consumer is trying to pickup incoming messages, or the likes, will now be processed as a message and handled by the routing Error Handler. By default the consumer will use the org.apache.camel.spi.ExceptionHandler to deal with exceptions, that will be logged at WARN or ERROR level and ignored. | false | boolean
 | *exceptionHandler* (consumer) | To let the consumer use a custom ExceptionHandler. Notice if the option bridgeErrorHandler is enabled then this option is not in use. By default the consumer will deal with exceptions, that will be logged at WARN or ERROR level and ignored. |  | ExceptionHandler
 | *exchangePattern* (consumer) | Sets the exchange pattern when the consumer creates an exchange. |  | ExchangePattern
diff --git a/components/camel-atomix/src/main/docs/atomix-multimap-component.adoc b/components/camel-atomix/src/main/docs/atomix-multimap-component.adoc
index 2204a5b..1ffb7fc 100644
--- a/components/camel-atomix/src/main/docs/atomix-multimap-component.adoc
+++ b/components/camel-atomix/src/main/docs/atomix-multimap-component.adoc
@@ -72,7 +72,7 @@ with the following path and query parameters:
 | *key* (consumer) | The key to use if none is set in the header or to listen for events for a specific key. |  | Object
 | *nodes* (consumer) | The address of the nodes composing the cluster. |  | String
 | *resultHeader* (consumer) | The header that wil carry the result. |  | String
-| *transport* (consumer) | Sets the Atomix transport. | io.atomix.catalyst.transport.netty.NettyTransport | Transport
+| *transportClassName* (consumer) | The class name (fqn) of the Atomix transport | io.atomix.catalyst.transport.netty.NettyTransport | String
 | *ttl* (consumer) | The resource ttl. |  | long
 | *exceptionHandler* (consumer) | To let the consumer use a custom ExceptionHandler. Notice if the option bridgeErrorHandler is enabled then this option is not in use. By default the consumer will deal with exceptions, that will be logged at WARN or ERROR level and ignored. |  | ExceptionHandler
 | *exchangePattern* (consumer) | Sets the exchange pattern when the consumer creates an exchange. |  | ExchangePattern
diff --git a/components/camel-atomix/src/main/docs/atomix-queue-component.adoc b/components/camel-atomix/src/main/docs/atomix-queue-component.adoc
index 78d9571..1003367 100644
--- a/components/camel-atomix/src/main/docs/atomix-queue-component.adoc
+++ b/components/camel-atomix/src/main/docs/atomix-queue-component.adoc
@@ -70,7 +70,7 @@ with the following path and query parameters:
 | *defaultAction* (common) | The default action. | ADD | Action
 | *nodes* (common) | The address of the nodes composing the cluster. |  | String
 | *resultHeader* (common) | The header that wil carry the result. |  | String
-| *transport* (common) | Sets the Atomix transport. | io.atomix.catalyst.transport.netty.NettyTransport | Transport
+| *transportClassName* (common) | The class name (fqn) of the Atomix transport | io.atomix.catalyst.transport.netty.NettyTransport | String
 | *bridgeErrorHandler* (consumer) | Allows for bridging the consumer to the Camel routing Error Handler, which mean any exceptions occurred while the consumer is trying to pickup incoming messages, or the likes, will now be processed as a message and handled by the routing Error Handler. By default the consumer will use the org.apache.camel.spi.ExceptionHandler to deal with exceptions, that will be logged at WARN or ERROR level and ignored. | false | boolean
 | *exceptionHandler* (consumer) | To let the consumer use a custom ExceptionHandler. Notice if the option bridgeErrorHandler is enabled then this option is not in use. By default the consumer will deal with exceptions, that will be logged at WARN or ERROR level and ignored. |  | ExceptionHandler
 | *exchangePattern* (consumer) | Sets the exchange pattern when the consumer creates an exchange. |  | ExchangePattern
diff --git a/components/camel-atomix/src/main/docs/atomix-set-component.adoc b/components/camel-atomix/src/main/docs/atomix-set-component.adoc
index 43bef07..4cf4806 100644
--- a/components/camel-atomix/src/main/docs/atomix-set-component.adoc
+++ b/components/camel-atomix/src/main/docs/atomix-set-component.adoc
@@ -70,7 +70,7 @@ with the following path and query parameters:
 | *defaultAction* (common) | The default action. | ADD | Action
 | *nodes* (common) | The address of the nodes composing the cluster. |  | String
 | *resultHeader* (common) | The header that wil carry the result. |  | String
-| *transport* (common) | Sets the Atomix transport. | io.atomix.catalyst.transport.netty.NettyTransport | Transport
+| *transportClassName* (common) | The class name (fqn) of the Atomix transport | io.atomix.catalyst.transport.netty.NettyTransport | String
 | *ttl* (common) | The resource ttl. |  | long
 | *bridgeErrorHandler* (consumer) | Allows for bridging the consumer to the Camel routing Error Handler, which mean any exceptions occurred while the consumer is trying to pickup incoming messages, or the likes, will now be processed as a message and handled by the routing Error Handler. By default the consumer will use the org.apache.camel.spi.ExceptionHandler to deal with exceptions, that will be logged at WARN or ERROR level and ignored. | false | boolean
 | *exceptionHandler* (consumer) | To let the consumer use a custom ExceptionHandler. Notice if the option bridgeErrorHandler is enabled then this option is not in use. By default the consumer will deal with exceptions, that will be logged at WARN or ERROR level and ignored. |  | ExceptionHandler
diff --git a/components/camel-atomix/src/main/docs/atomix-value-component.adoc b/components/camel-atomix/src/main/docs/atomix-value-component.adoc
index 30e6c5c..8ce04f1 100644
--- a/components/camel-atomix/src/main/docs/atomix-value-component.adoc
+++ b/components/camel-atomix/src/main/docs/atomix-value-component.adoc
@@ -70,7 +70,7 @@ with the following path and query parameters:
 | *defaultAction* (common) | The default action. | SET | Action
 | *nodes* (common) | The address of the nodes composing the cluster. |  | String
 | *resultHeader* (common) | The header that wil carry the result. |  | String
-| *transport* (common) | Sets the Atomix transport. | io.atomix.catalyst.transport.netty.NettyTransport | Transport
+| *transportClassName* (common) | The class name (fqn) of the Atomix transport | io.atomix.catalyst.transport.netty.NettyTransport | String
 | *ttl* (common) | The resource ttl. |  | long
 | *bridgeErrorHandler* (consumer) | Allows for bridging the consumer to the Camel routing Error Handler, which mean any exceptions occurred while the consumer is trying to pickup incoming messages, or the likes, will now be processed as a message and handled by the routing Error Handler. By default the consumer will use the org.apache.camel.spi.ExceptionHandler to deal with exceptions, that will be logged at WARN or ERROR level and ignored. | false | boolean
 | *exceptionHandler* (consumer) | To let the consumer use a custom ExceptionHandler. Notice if the option bridgeErrorHandler is enabled then this option is not in use. By default the consumer will deal with exceptions, that will be logged at WARN or ERROR level and ignored. |  | ExceptionHandler
diff --git a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMapEndpointBuilderFactory.java b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMapEndpointBuilderFactory.java
index 60d2b88..a993d8c 100644
--- a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMapEndpointBuilderFactory.java
+++ b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMapEndpointBuilderFactory.java
@@ -166,28 +166,15 @@ public interface AtomixMapEndpointBuilderFactory {
             return this;
         }
         /**
          * Sets the Atomix transport.
          * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixMapEndpointConsumerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixMapEndpointConsumerBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixMapEndpointConsumerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -659,28 +646,15 @@ public interface AtomixMapEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixMapEndpointProducerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixMapEndpointProducerBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixMapEndpointProducerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -1096,27 +1070,15 @@ public interface AtomixMapEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * Group: common
-         */
-        default AtomixMapEndpointBuilder transport(Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixMapEndpointBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixMapEndpointBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -166,28 +166,15 @@ public interface AtomixMapEndpointBuilderFactory {
         }
         /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
diff --git a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMessagingEndpointBuilderFactory.java b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMessagingEndpointBuilderFactory.java
index e4a3139..3199b73 100644
--- a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMessagingEndpointBuilderFactory.java
+++ b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMessagingEndpointBuilderFactory.java
@@ -192,29 +192,15 @@ public interface AtomixMessagingEndpointBuilderFactory {
             return this;
         }
         /**
          * Sets the Atomix transport.
          * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixMessagingEndpointConsumerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixMessagingEndpointConsumerBuilder transport(
-                String transport) {
-            setProperty("transport", transport);
+        default AtomixMessagingEndpointConsumerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -691,29 +677,15 @@ public interface AtomixMessagingEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixMessagingEndpointProducerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixMessagingEndpointProducerBuilder transport(
-                String transport) {
-            setProperty("transport", transport);
+        default AtomixMessagingEndpointProducerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -1134,27 +1106,15 @@ public interface AtomixMessagingEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * Group: common
-         */
-        default AtomixMessagingEndpointBuilder transport(Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixMessagingEndpointBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixMessagingEndpointBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
     }
@@ -192,29 +192,15 @@ public interface AtomixMessagingEndpointBuilderFactory {
         }
         /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
diff --git a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMultiMapEndpointBuilderFactory.java b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMultiMapEndpointBuilderFactory.java
index 5ce13b7..7414f39 100644
--- a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMultiMapEndpointBuilderFactory.java
+++ b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixMultiMapEndpointBuilderFactory.java
@@ -162,27 +162,15 @@ public interface AtomixMultiMapEndpointBuilderFactory {
             return this;
         }
         /**
          * Sets the Atomix transport.
          * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: consumer
-         */
-        default AtomixMultiMapEndpointBuilder transport(Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: consumer
          */
-        default AtomixMultiMapEndpointBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixMultiMapEndpointBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -162,27 +162,15 @@ public interface AtomixMultiMapEndpointBuilderFactory {
         }
         /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
diff --git a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixQueueEndpointBuilderFactory.java b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixQueueEndpointBuilderFactory.java
index aeb44a0..80d55f8 100644
--- a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixQueueEndpointBuilderFactory.java
+++ b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixQueueEndpointBuilderFactory.java
@@ -142,28 +142,15 @@ public interface AtomixQueueEndpointBuilderFactory {
             return this;
         }
         /**
          * Sets the Atomix transport.
          * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixQueueEndpointConsumerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixQueueEndpointConsumerBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixQueueEndpointConsumerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -589,28 +576,15 @@ public interface AtomixQueueEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixQueueEndpointProducerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixQueueEndpointProducerBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixQueueEndpointProducerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -980,27 +954,15 @@ public interface AtomixQueueEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * Group: common
-         */
-        default AtomixQueueEndpointBuilder transport(Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixQueueEndpointBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixQueueEndpointBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
     }
@@ -142,28 +142,15 @@ public interface AtomixQueueEndpointBuilderFactory {
         }
         /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
diff --git a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixSetEndpointBuilderFactory.java b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixSetEndpointBuilderFactory.java
index 7b230e8..9bbcc49 100644
--- a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixSetEndpointBuilderFactory.java
+++ b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixSetEndpointBuilderFactory.java
@@ -142,28 +142,15 @@ public interface AtomixSetEndpointBuilderFactory {
             return this;
         }
         /**
          * Sets the Atomix transport.
          * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixSetEndpointConsumerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixSetEndpointConsumerBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixSetEndpointConsumerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -611,28 +598,15 @@ public interface AtomixSetEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixSetEndpointProducerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixSetEndpointProducerBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixSetEndpointProducerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -1024,27 +998,15 @@ public interface AtomixSetEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * Group: common
-         */
-        default AtomixSetEndpointBuilder transport(Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixSetEndpointBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixSetEndpointBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -142,28 +142,15 @@ public interface AtomixSetEndpointBuilderFactory {
         }
         /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
diff --git a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixValueEndpointBuilderFactory.java b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixValueEndpointBuilderFactory.java
index b2a886a..7847afd 100644
--- a/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixValueEndpointBuilderFactory.java
+++ b/core/camel-endpointdsl/src/main/java/org/apache/camel/builder/endpoint/dsl/AtomixValueEndpointBuilderFactory.java
@@ -142,28 +142,15 @@ public interface AtomixValueEndpointBuilderFactory {
             return this;
         }
         /**
          * Sets the Atomix transport.
          * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixValueEndpointConsumerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixValueEndpointConsumerBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixValueEndpointConsumerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -611,28 +598,15 @@ public interface AtomixValueEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
-         * 
-         * Group: common
-         */
-        default AtomixValueEndpointProducerBuilder transport(
-                Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixValueEndpointProducerBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixValueEndpointProducerBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -1024,27 +998,15 @@ public interface AtomixValueEndpointBuilderFactory {
             return this;
         }
         /**
-         * Sets the Atomix transport.
-         * 
-         * The option is a:
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The class name (fqn) of the Atomix transport.
          * 
-         * Group: common
-         */
-        default AtomixValueEndpointBuilder transport(Class<Object> transport) {
-            setProperty("transport", transport);
-            return this;
-        }
-        /**
-         * Sets the Atomix transport.
-         * 
-         * The option will be converted to a
-         * <code>java.lang.Class&lt;io.atomix.catalyst.transport.Transport&gt;</code> type.
+         * The option is a: <code>java.lang.String</code> type.
          * 
          * Group: common
          */
-        default AtomixValueEndpointBuilder transport(String transport) {
-            setProperty("transport", transport);
+        default AtomixValueEndpointBuilder transportClassName(
+                String transportClassName) {
+            setProperty("transportClassName", transportClassName);
             return this;
         }
         /**
@@ -142,28 +142,15 @@ public interface AtomixValueEndpointBuilderFactory {
         }
         /**
-         * Sets the Atomix transport.
+         * The class name (fqn) of the Atomix transport.
          * 